pyeq3: an equation, curve and surface fitting library
=====================================================

pyeq3 is a large collection of python3 equations that perform curve fitting on 2D and 3D data,
output source code in several computing languages, and run a genetic algorithm for initial parameter estimation.
The module comes with cluster, parallel, IPython, GUI, NodeJS, and web-based graphical examples.
It includes orthogonal distance and relative error regressions.

pyeq3 is released under a permissive license. It relies on numpy, scipy, and matplotlib.

 - Homepage: https://github.com/equations-project/pyeq3
 - Discussion group: https://groups.google.com/g/findcurves
 - Documentation: http://pyeq3.readthedocs.io
 - Source code with examples: https://github.com/equations-project/pyeq3

If you haven't yet installed pyeq3, you can go straight to :ref:`ref-installation` for detailed
instructions. After that, you might want to try out some :ref:`ref-examples`.

.. toctree::
  :maxdepth: 4

  introduction
  model_list
  zreferences
